==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/GRID.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}METADATA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}DATA" minOccurs="0"/>
 *         &lt;element name="TOTAL-COUNT" minOccurs="0">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}FIELDS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "metadata",
    "data",
    "totalcount",
    "fields"
})
@XmlRootElement(name = "GRID")
public class GRID {

    @XmlElement(name = "METADATA")
    protected METADATA metadata;
    @XmlElement(name = "DATA")
    protected DATA data;
    @XmlElement(name = "TOTAL-COUNT")
    protected String totalcount;
    @XmlElement(name = "FIELDS")
    protected FIELDS fields;

    /**
     * Obtient la valeur de la propriété metadata.
     * 
     * @return
     *     possible object is
     *     {@link METADATA }
     *     
     */
    public METADATA getMETADATA() {
        return metadata;
    }

    /**
     * Définit la valeur de la propriété metadata.
     * 
     * @param value
     *     allowed object is
     *     {@link METADATA }
     *     
     */
    public void setMETADATA(METADATA value) {
        this.metadata = value;
    }

    /**
     * Obtient la valeur de la propriété data.
     * 
     * @return
     *     possible object is
     *     {@link DATA }
     *     
     */
    public DATA getDATA() {
        return data;
    }

    /**
     * Définit la valeur de la propriété data.
     * 
     * @param value
     *     allowed object is
     *     {@link DATA }
     *     
     */
    public void setDATA(DATA value) {
        this.data = value;
    }

    /**
     * Obtient la valeur de la propriété totalcount.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOTALCOUNT() {
        return totalcount;
    }

    /**
     * Définit la valeur de la propriété totalcount.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOTALCOUNT(String value) {
        this.totalcount = value;
    }

    /**
     * Obtient la valeur de la propriété fields.
     * 
     * @return
     *     possible object is
     *     {@link FIELDS }
     *     
     */
    public FIELDS getFIELDS() {
        return fields;
    }

    /**
     * Définit la valeur de la propriété fields.
     * 
     * @param value
     *     allowed object is
     *     {@link FIELDS }
     *     
     */
    public void setFIELDS(FIELDS value) {
        this.fields = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/GRID.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}METADATA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}DATA" minOccurs="0"/>
 *         &lt;element name="TOTAL-COUNT" minOccurs="0">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0116_GetGridDataOnly_001_Result}FIELDS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "metadata",
    "data",
    "totalcount",
    "fields"
})
@XmlRootElement(name = "GRID")
public class GRID {

    @XmlElement(name = "METADATA")
    protected METADATA metadata;
    @XmlElement(name = "DATA")
    protected DATA data;
    @XmlElement(name = "TOTAL-COUNT")
    protected String totalcount;
    @XmlElement(name = "FIELDS")
    protected FIELDS fields;

    /**
     * Gets the value of the metadata property.
     * 
     * @return
     *     possible object is
     *     {@link METADATA }
     *     
     */
    public METADATA getMETADATA() {
        return metadata;
    }

    /**
     * Sets the value of the metadata property.
     * 
     * @param value
     *     allowed object is
     *     {@link METADATA }
     *     
     */
    public void setMETADATA(METADATA value) {
        this.metadata = value;
    }

    /**
     * Gets the value of the data property.
     * 
     * @return
     *     possible object is
     *     {@link DATA }
     *     
     */
    public DATA getDATA() {
        return data;
    }

    /**
     * Sets the value of the data property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATA }
     *     
     */
    public void setDATA(DATA value) {
        this.data = value;
    }

    /**
     * Gets the value of the totalcount property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOTALCOUNT() {
        return totalcount;
    }

    /**
     * Sets the value of the totalcount property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOTALCOUNT(String value) {
        this.totalcount = value;
    }

    /**
     * Gets the value of the fields property.
     * 
     * @return
     *     possible object is
     *     {@link FIELDS }
     *     
     */
    public FIELDS getFIELDS() {
        return fields;
    }

    /**
     * Sets the value of the fields property.
     * 
     * @param value
     *     allowed object is
     *     {@link FIELDS }
     *     
     */
    public void setFIELDS(FIELDS value) {
        this.fields = value;
    }

}
